==> 1.0.2_20240315_release.zip: app/client/admin/C_system_upgrade.php <==
<?php

namespace app\client\admin;

class C_system_upgrade
{
    /**
     * 下载文件
     * @param string $paramObj
     */
    public function downloadFile($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("L_Admin_systemUpgrade")->downloadFile($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }

    /**
     * 安装文件
     * @param string $paramObj
     */
    public function installFile($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("L_Admin_systemUpgrade")->install($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }

    /**
     * 安装文件
     * @param string $paramObj
     */
    public function install($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("L_Admin_systemUpgrade")->install($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }

    /**
     * 安装脚本
     * @param string $paramObj
     */
    public function execScript($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("L_Admin_systemUpgrade")->execScript($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }

    /**
     * 详情
     * @param string $paramObj
     */
    public function info($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("T_Api_software_upgrade")->info($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }

    /**
     * 获取下载文件
     * @param string $paramObj
     */
    public function getDownFile($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("T_Api_software_upgrade")->getDownFile($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }
}

==> 1.0.20_20240718_release.zip: app/client/admin/C_system_upgrade.php <==
<?php

namespace app\client\admin;

class C_system_upgrade
{
    /**
     * 下载文件
     * @param string $paramObj
     */
    public function downloadFile($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("L_Admin_systemUpgrade")->downloadFile($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }

    /**
     * 安装文件
     * @param string $paramObj
     */
    public function installFile($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("L_Admin_systemUpgrade")->install($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }

    /**
     * 安装文件
     * @param string $paramObj
     */
    public function install($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("L_Admin_systemUpgrade")->install($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }

    /**
     * 安装脚本
     * @param string $paramObj
     */
    public function execScript($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("L_Admin_systemUpgrade")->execScript($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }

    /**
     * 详情
     * @param string $paramObj
     */
    public function info($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("T_Api_software_upgrade")->info($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }

    /**
     * 获取下载文件
     * @param string $paramObj
     */
    public function getDownFile($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("T_Api_software_upgrade")->getDownFile($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }

    /**
     * 更新key
     * @param string $paramObj
     */
    public function updateKey($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("L_Api_goods")->updateKey($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }

    /**
     * 更新白名单
     * @param string $paramObj
     */
    public function updateWhiteList($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("L_Api_goods")->updateWhiteList($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }

    /**
     * 获取程序版本
     * @param string $paramObj
     */
    public function cmsProject($paramObj=""){
        $paramsObj=paramsObj();
        $paramsObj->mixed=1;
        $paramsObj=blenderObject($paramsObj,$paramObj);
        $checkResult=app("L_Api_goods")->cmsProject($paramsObj);
        if($checkResult["error_no"]==0){
            $result=$checkResult["result"];
            return apiResult(true,"success",0,$result,$checkResult["extra"]);
        }else{
            recordErrorLog($checkResult); //记录错误信息
            return apiResult(false,$checkResult["error_msg"],$checkResult["error_no"]);
        }
    }
}
